@@ -11,8 +11,8 @@
 #' @param chrom an object of class chrom.
 #' @param boxp logical specifying whether marginal boxplots should be plotted [T/F].
 #' @param dp.alpha degree of transparency applied to points in dot plots [0-255].
-#' @param chrom.s	start position for the chromosome.
-#' @param chrom.e	end position for the chromosome.
+#' @param chrom.s	start position for the chromosome. (Deprecated. use xlim)
+#' @param chrom.e	end position for the chromosome. (Deprecated. use xlim)
 #' @param drlist1 a named list containing elements to create a drplot
 #' @param drlist2 a named list containing elements to create a drplot
 #' @param drlist3 a named list containing elements to create a drplot
@@ -51,6 +51,20 @@ chromo <- function( chrom,
     stop("Expecting object of class chromR")
   }
   
+  if( chrom.s != 1 | !is.null(chrom.e) ){
+    stop("The parameters 'chrom.s' and 'chrom.e' were deprecated in vcfR v1.5.0. Please use 'xlim' instead")
+  }
+  
+  myDots <- list(...)
+  
+  if( !is.null( myDots$xlim ) ){
+    chrom.s <- myDots$xlim[1]
+    chrom.e <- myDots$xlim[2]
+  } else {
+    chrom.s <- 1
+    chrom.e <- length(chrom)
+  }
+  
   # Test to see if the mask is populated.
 #  if( length(grep('mask', colnames(chrom@var.info))) < 1 ){
 #    chrom@var.info$mask <- rep( TRUE, times=nrow(chrom@vcf@fix) )
@@ -463,7 +477,7 @@ chromoqc <- function( chrom,
   )
   
   chromo( chrom, boxp = boxp, 
-          chrom.e = chrom@len, 
+#          chrom.e = chrom@len,
           drlist1 = myList1,
           drlist2 = myList2,
           drlist3 = myList3,
@@ -481,4 +495,4 @@ chromoqc <- function( chrom,
 
 
 ##### ##### ##### ##### #####
-# EOF.
\ No newline at end of file
+# EOF.
