@@ -1,28 +1,17 @@
-#'
-#' @rdname vcfR-method
-#' @title vcfR-method
-#' 
-#' @aliases vcfR-method
-#' 
-#' @description
-#' Methods to show, subset or plot data from objects of class vcfR
-#' 
-#' @param object object1 of class vcfR
-#' @param x object of class vcfR
-#' @param n number of rows to print
-#' @param maxchar maximum number of characters to print per line
-#' 
-#' 
-#' 
-#' 
-#' 
 
 
-
-#' ##### Method show #####
+##### Method show #####
 #' 
 #' @rdname vcfR-method
-#' @aliases show.vcfR
+# ' @aliases show.vcfR,show,vcfR-method
+# ' @aliases show,vcfR-method
+#' @title show
+#' 
+#' @description 
+#' Display a summary of a vcfR object.
+#' 
+#' @param object a vcfR object
+#' 
 #' @details 
 #' The method \strong{show} is used to display an object.
 #' Because vcf data are relatively large, this has been abbreviated.
@@ -34,13 +23,19 @@ setMethod(
   signature = "vcfR",
   definition=function(object){
     
-    nsamp <- ncol(object@gt) - 1
+    if( ncol(object@gt) > 1 ){
+      nsamp <- ncol(object@gt) - 1
+    } else {
+      nsamp <- 0
+    }
+    nchrom <- length( unique( getCHROM( object ) ) )
     nvar <- nrow(object@gt)
     nna <- sum( is.na(object@gt[,-1]) )
     pna <- nna / c( nsamp * nvar )
 
     cat("***** Object of Class vcfR *****\n")
     cat( paste( nsamp, "samples\n") )
+    cat( paste( nchrom, "CHROMs\n") )
     cat( paste( format(nvar, big.mark=","), "variants\n") )
     cat( "Object size: ")
     print(object.size(object), units="MB")
@@ -51,11 +46,19 @@ setMethod(
 )
 
 
-
 #### Method head ####
 #' 
+#' @name head
 #' @rdname vcfR-method
 #' @title head
+#' @aliases head,vcfR-method
+#' @docType methods
+#' 
+#' @param x object of class vcfR
+#' @param n number of rows to print
+#' @param maxchar maximum number of characters to print per line
+#' @param ... arguments to be passed to other methods
+#' 
 #' @description \strong{head} returns the first parts of an object of class vcfR.
 #' 
 #' @details 
@@ -130,22 +133,57 @@ setMethod(
 #' The columns in the fix slot will not be subset by j.
 #' The parameter j is a vector used to subset the columns of the gt slot.
 #' Note that it is essential to include the first column here (FORMAT) or downsream processes will encounter trouble.
-
+#' 
+#' The \strong{samples} parameter allows another way to select samples.
+#' Because the first column of the gt section is the FORMAT column you typically need to include that column and sample numbers therefore begin at two.
+#' Use of the samples parameter allows you to select columns by a vector of numerics, logicals or characters.
+#' When numerics are used the samples can be selected starting at one.
+#' The function will then add one to this vector and include one to select the desired samples and the FORMAT column.
+#' When a vector of characters is used it should contain the desired sample names.
+#' The function will add the FORMAT column if it is not the first element.
+#' When a vector of logicals is used a TRUE will be added to the vector to ensure the FORMAT column is selected.
+#' Note that specification of samples will override specification of j.
+#' 
 #' 
 # @export
 # @aliases []
 #'
 #' @param i vector of rows (variants) to include
 #' @param j vector of columns (samples) to include
+#' @param samples vector (numeric, character or logical) specifying samples, see details
 #' @param drop delete the dimensions of an array which only has one level
 #'
 setMethod(
   f= "[",
-#  signature="vcfR",
-  signature(x = "vcfR", i = "ANY", j="ANY"),
-  definition=function(x, i, j, ..., drop){
+  signature(x = "vcfR"),
+#  signature(x = "vcfR", i = "ANY", j = "ANY"),
+#  signature(x = "vcfR", i = "ANY", j = "ANY", samples = "ANY"),
+  definition=function(x, i, j, samples = NULL, ..., drop){
+#  definition=function(x, i, j, ..., drop){
+    if( !is.null(samples) ){
+      if( inherits(samples, what  = c("numeric", "integer") ) ){
+        samples <- samples + 1
+        j <- c(1, samples)
+      } else if( inherits(samples, what  = "character") ){
+        if( samples[1] != "FORMAT" ){ 
+          j <- c("FORMAT", samples)
+        } else {
+          j <- samples
+        }
+      } else if( inherits(samples, what  = "logical") ){
+        j <- c(TRUE, samples)
+      } else {
+        stop(paste("samples specified, expecting a numeric, character or logical but received", class(samples)))
+      }
+    }
+    
     x@fix <- x@fix[ i, , drop = FALSE ]
     x@gt <- x@gt[ i, j, drop = FALSE ]
+    
+    if( colnames(x@gt)[1] != 'FORMAT' ){
+      warning("You have chosen to omit the FORMAT column, this is typically undesireable.")
+    }
+    
     return(x)
   }
 )
@@ -158,10 +196,10 @@ setGeneric("plot")
 #' @title plot.vcfR
 #' @description The \strong{plot} method visualizes objects of class vcfR
 # @export
-#' @aliases plot.vcfR
+# ' @aliases plot.vcfR
+# ' @aliases vcfR,vcfR-method
 #' 
 #' @param y not used
-#' @param ... Arguments to be passed to methods
 #' 
 #' @details 
 #' The \strong{plot} method generates a histogram from data found in the 'QUAL' column from the 'fix' slot.
@@ -184,45 +222,6 @@ setMethod(
 ##### ##### ##### ##### #####
 
 
-#setGeneric("rbind", signature="...")
-#setGeneric("rbind")
-# '
-# ' @rdname vcfR-method
-# ' @aliases rbind.vcfR, rbind
-# ' 
-# ' @param deparse.level integer controlling the construction of labels. see ?rbind.
-#  @param ... objects of class vcfR passed to rbind
-# ' 
-# ' @export
-# '
-#setMethod(
-#  f = "rbind",
-#  signature = "vcfR", 
-#  definition = function( ..., deparse.level=1 )
-#  {
-    ## store arguments
-#    dots <- list(...)
-
-    ## extract arguments which are vcfR objects
-#    myList <- dots[sapply(dots, inherits, "vcfR")]
-#    if(!all(sapply(myList, class)=="vcfR")) stop("some objects are not vcfR objects")
-    
-    ## keep the rest in 'dots'
-#    dots <- dots[!sapply(dots, inherits, "vcfR")]
-    
-    # Initialize
-#    x <- myList[[1]]
-    
-    # Implement
-#    x@fix <- do.call( rbind, lapply( myList, function(x){ x@fix } ) )
-#    x@gt  <- do.call( rbind, lapply( myList, function(x){ x@gt  } ) )
-
-#    return(x)
-#  }
-#)
-
-
-
 setMethod("rbind",
   signature( "vcfR" ),
   function (..., deparse.level = 0) 
@@ -250,6 +249,7 @@ setMethod("rbind",
 )
 
 
+
 #' @rdname vcfR-method
 #' @aliases rbind2.vcfR
 #' 
@@ -292,6 +292,7 @@ setMethod("rbind2",
 )
 
 
+
 ##### ##### ##### ##### #####
 #
 # nrow
