@@ -15,11 +15,21 @@ test_that("chromR show",{
   expect_null(tmp)
 })
 
-test_that("chromR plot",{
-#  tmp <- plot(chrom)
+
+##### ##### ##### ##### #####
+
+test_that("chromR length",{
+  data("vcfR_example")
+  chrom <- create.chromR(name="Supercontig_1.50", vcf=vcf, verbose=FALSE)
+  expect_equal(length(chrom), chrom@len)
+  
+#  tmp <- print(chrom)
 #  expect_true(is.null(tmp))
 })
 
+
+##### ##### ##### ##### #####
+
 test_that("chromR print",{
 #  tmp <- print(chrom)
 #  expect_true(is.null(tmp))
